# squidpy-GPU: `gr`

{mod}`squidpy.gr` is a tool for the analysis of spatial molecular data {cite}`Palla2022`.
{mod}`rapids_singlecell.gr` accelerates some of these functions.

```{eval-rst}
.. module:: rapids_singlecell.gr
.. currentmodule:: rapids_singlecell

.. autosummary::
    :toctree: generated

    gr.spatial_autocorr
    gr.co_occurrence
    gr.ligrec
```
